@@ -154,7 +154,12 @@ void ResourcesUpdatesModel::init()
     m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
 
     KConfigWatcher::Ptr watcher = KConfigWatcher::create(sharedConfig);
-    connect(watcher.data(), &KConfigWatcher::configChanged, [=]() {
+    connect(watcher.data(), &KConfigWatcher::configChanged, [this](const KConfigGroup &group, const QByteArrayList &names) {
+        // Ensure it is for the right file
+        if (!names.contains("UseOfflineUpdates") || group.name() != "Software") {
+            return;
+        }
+
         if (m_offlineUpdates == group.readEntry<bool>("UseOfflineUpdates", false)) {
             return;
         }
@@ -281,7 +286,7 @@ double ResourcesUpdatesModel::updateSize() const
 {
     double ret = 0.;
     for (AbstractBackendUpdater *upd : m_updaters) {
-        ret += upd->updateSize();
+        ret += std::max(0., upd->updateSize());
     }
     return ret;
 }
@@ -314,6 +319,13 @@ bool ResourcesUpdatesModel::needsReboot() const
     return false;
 }
 
+bool ResourcesUpdatesModel::readyToReboot() const
+{
+    return kContains(m_updaters, [](AbstractBackendUpdater *updater) {
+        return !updater->needsReboot() || updater->isReadyToReboot();
+    });
+}
+
 bool ResourcesUpdatesModel::useUnattendedUpdates() const
 {
     return m_offlineUpdates;
